This is the mail archive of the gdb-patches@sourceware.org mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[PUSHED] inf-child.c: Update comments.


This file is no longer used exclusively by Unix targets anymore.

gdb/
2014-03-12  Pedro Alves  <palves@redhat.com>

	* inf-child.c: Update top comment to not mention Unix.  Add
	generic comment describing how this target is meant to be used.
	(inf_child_post_attach, inf_child_post_startup_inferior)
	(inf_child_follow_fork, inf_child_pid_to_exec_file): Don't mention
	Unix in comment.
---
 gdb/ChangeLog   |  8 ++++++++
 gdb/inf-child.c | 23 +++++++++++++----------
 2 files changed, 21 insertions(+), 10 deletions(-)

diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index abfbfd7..f8d9d05 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,5 +1,13 @@
 2014-03-12  Pedro Alves  <palves@redhat.com>
 
+	* inf-child.c: Update top comment to not mention Unix.  Add
+	generic comment describing how this target is meant to be used.
+	(inf_child_post_attach, inf_child_post_startup_inferior)
+	(inf_child_follow_fork, inf_child_pid_to_exec_file): Don't mention
+	Unix in comment.
+
+2014-03-12  Pedro Alves  <palves@redhat.com>
+
 	* nto-procfs.c: Include inf-child.h.
 	(procfs_ops): Delete global.
 	(procfs_can_run): Delete method.
diff --git a/gdb/inf-child.c b/gdb/inf-child.c
index fd03a9f..ee63dd1 100644
--- a/gdb/inf-child.c
+++ b/gdb/inf-child.c
@@ -1,5 +1,4 @@
-/* Default child (native) target interface, for GDB when running under
-   Unix.
+/* Base/prototype target for default child (native) targets.
 
    Copyright (C) 1988-2014 Free Software Foundation, Inc.
 
@@ -18,6 +17,11 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
+/* This file provides a common base class/target that all native
+   target implementations extend, by calling inf_child_target to get a
+   new prototype target and then overriding target methods as
+   necessary.  */
+
 #include "defs.h"
 #include "regcache.h"
 #include "memattr.h"
@@ -89,8 +93,8 @@ inf_child_store_inferior_registers (struct target_ops *ops,
 static void
 inf_child_post_attach (struct target_ops *self, int pid)
 {
-  /* This version of Unix doesn't require a meaningful "post attach"
-     operation by a debugger.  */
+  /* This target doesn't require a meaningful "post attach" operation
+     by a debugger.  */
 }
 
 /* Get ready to modify the registers array.  On machines which store
@@ -114,16 +118,15 @@ inf_child_open (char *arg, int from_tty)
 static void
 inf_child_post_startup_inferior (struct target_ops *self, ptid_t ptid)
 {
-  /* This version of Unix doesn't require a meaningful "post startup
-     inferior" operation by a debugger.  */
+  /* This target doesn't require a meaningful "post startup inferior"
+     operation by a debugger.  */
 }
 
 static int
 inf_child_follow_fork (struct target_ops *ops, int follow_child,
 		       int detach_fork)
 {
-  /* This version of Unix doesn't support following fork or vfork
-     events.  */
+  /* This target doesn't support following fork or vfork events.  */
   return 0;
 }
 
@@ -136,8 +139,8 @@ inf_child_can_run (struct target_ops *self)
 static char *
 inf_child_pid_to_exec_file (struct target_ops *self, int pid)
 {
-  /* This version of Unix doesn't support translation of a process ID
-     to the filename of the executable file.  */
+  /* This target doesn't support translation of a process ID to the
+     filename of the executable file.  */
   return NULL;
 }
 
-- 
1.7.11.7


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]